DeviceBaseInfo

Struct DeviceBaseInfo 

pub struct DeviceBaseInfo {
    pub rx_depth: Option<u16>,
    pub tx_depth: Option<u16>,
    pub buffer_alignment: Option<u32>,
    pub max_buffer_length: Option<u32>,
    pub min_rx_buffer_length: Option<u32>,
    pub min_tx_buffer_length: Option<u32>,
    pub min_tx_buffer_head: Option<u16>,
    pub min_tx_buffer_tail: Option<u16>,
    pub max_buffer_parts: Option<u8>,
    pub min_rx_buffers: Option<u16>,
    /* private fields */
}
Network device base info.

Fields

rx_depth: Option<u16>

Maximum number of items in rx FIFO (per session). Required.

rx_depth is calculated based on the size of the actual backing hardware rx queue.

tx_depth: Option<u16>

Maximum number of items in tx FIFO (per session). Required.

tx_depth is calculated based on the size of the actual backing hardware tx queue.

buffer_alignment: Option<u32>

Alignment requirement for buffers in the data VMO.

All buffers in the data VMO must be aligned to buffer_alignment relative to the start of the VMO. buffer_alignment == 0 is never reported. Required.

max_buffer_length: Option<u32>

Maximum supported length of buffers in the data VMO, in bytes.

Absent if no maximum buffer length is defined. Must be nonzero.

min_rx_buffer_length: Option<u32>

The minimum rx buffer length required for device. Required.

min_tx_buffer_length: Option<u32>

The minimum tx buffer length required for the device. Required.

This value accounts only for tx payload length, min_tx_buffer_head and min_tx_buffer_tail are not part of this value.

Clients must zero pad outgoing frames to meet the required minimum length.

min_tx_buffer_head: Option<u16>

The number of bytes the device requests be free as head space in a tx buffer. Required.

min_tx_buffer_tail: Option<u16>

The amount of bytes the device requests be free as tail space in a tx buffer. Required.

max_buffer_parts: Option<u8>

Maximum descriptor chain length accepted by the device. Required.

min_rx_buffers: Option<u16>

Minimum amount of Rx buffers the client needs to prepare for the network device. Client should use this information to select its VMO sizes if using multi-VMO support.