pub struct SessionRegisterForTxRequest {
pub vmos: Vec<u8>,
}Fields
vmos: Vec<u8>Trait Implementations
Sourceimpl Debug for SessionRegisterForTxRequest
impl Debug for SessionRegisterForTxRequest
Sourceimpl Decode<SessionRegisterForTxRequest, DefaultFuchsiaResourceDialect> for SessionRegisterForTxRequest
impl Decode<SessionRegisterForTxRequest, DefaultFuchsiaResourceDialect> for SessionRegisterForTxRequest
Sourceimpl Encode<SessionRegisterForTxRequest, DefaultFuchsiaResourceDialect> for &mut SessionRegisterForTxRequest
impl Encode<SessionRegisterForTxRequest, DefaultFuchsiaResourceDialect> for &mut SessionRegisterForTxRequest
Sourceimpl<T0: Encode<Vector<u8, 32>, DefaultFuchsiaResourceDialect>> Encode<SessionRegisterForTxRequest, DefaultFuchsiaResourceDialect> for (T0,)
impl<T0: Encode<Vector<u8, 32>, DefaultFuchsiaResourceDialect>> Encode<SessionRegisterForTxRequest, DefaultFuchsiaResourceDialect> for (T0,)
Sourceimpl Hash for SessionRegisterForTxRequest
impl Hash for SessionRegisterForTxRequest
Sourceimpl Ord for SessionRegisterForTxRequest
impl Ord for SessionRegisterForTxRequest
Sourcefn cmp(&self, other: &SessionRegisterForTxRequest) -> Ordering
fn cmp(&self, other: &SessionRegisterForTxRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for SessionRegisterForTxRequest
impl PartialOrd for SessionRegisterForTxRequest
Sourceimpl ResourceTypeMarker for SessionRegisterForTxRequest
impl ResourceTypeMarker for SessionRegisterForTxRequest
Sourcetype Borrowed<'a> = &'a mut SessionRegisterForTxRequest
type Borrowed<'a> = &'a mut SessionRegisterForTxRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).Sourceimpl TypeMarker for SessionRegisterForTxRequest
impl TypeMarker for SessionRegisterForTxRequest
Sourcetype Owned = SessionRegisterForTxRequest
type Owned = SessionRegisterForTxRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.impl Eq for SessionRegisterForTxRequest
impl Standalone<DefaultFuchsiaResourceDialect> for SessionRegisterForTxRequest
impl StructuralPartialEq for SessionRegisterForTxRequest