#[repr(C)]pub struct SessionRegisterForTxResponse {
pub successful: u8,
pub status: i32,
}Fields
successful: u8status: i32Trait Implementations
Sourceimpl Clone for SessionRegisterForTxResponse
impl Clone for SessionRegisterForTxResponse
Sourcefn clone(&self) -> SessionRegisterForTxResponse
fn clone(&self) -> SessionRegisterForTxResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionRegisterForTxResponse
impl Debug for SessionRegisterForTxResponse
Sourceimpl<D> Decode<SessionRegisterForTxResponse, D> for SessionRegisterForTxResponsewhere
D: ResourceDialect,
impl<D> Decode<SessionRegisterForTxResponse, D> for SessionRegisterForTxResponsewhere
D: ResourceDialect,
Sourcefn new_empty() -> SessionRegisterForTxResponse
fn new_empty() -> SessionRegisterForTxResponse
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<SessionRegisterForTxResponse, D> for &SessionRegisterForTxResponsewhere
D: ResourceDialect,
impl<D> Encode<SessionRegisterForTxResponse, D> for &SessionRegisterForTxResponsewhere
D: ResourceDialect,
Sourceimpl Hash for SessionRegisterForTxResponse
impl Hash for SessionRegisterForTxResponse
Sourceimpl Ord for SessionRegisterForTxResponse
impl Ord for SessionRegisterForTxResponse
Sourcefn cmp(&self, other: &SessionRegisterForTxResponse) -> Ordering
fn cmp(&self, other: &SessionRegisterForTxResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SessionRegisterForTxResponse
impl PartialEq for SessionRegisterForTxResponse
Sourcefn eq(&self, other: &SessionRegisterForTxResponse) -> bool
fn eq(&self, other: &SessionRegisterForTxResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for SessionRegisterForTxResponse
impl PartialOrd for SessionRegisterForTxResponse
Sourceimpl TypeMarker for SessionRegisterForTxResponse
impl TypeMarker for SessionRegisterForTxResponse
Sourcetype Owned = SessionRegisterForTxResponse
type Owned = SessionRegisterForTxResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for SessionRegisterForTxResponse
impl ValueTypeMarker for SessionRegisterForTxResponse
Sourcetype Borrowed<'a> = &'a SessionRegisterForTxResponse
type Borrowed<'a> = &'a SessionRegisterForTxResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<SessionRegisterForTxResponse as TypeMarker>::Owned,
) -> <SessionRegisterForTxResponse as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<SessionRegisterForTxResponse as TypeMarker>::Owned, ) -> <SessionRegisterForTxResponse as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Copy for SessionRegisterForTxResponse
impl Eq for SessionRegisterForTxResponse
impl Persistable for SessionRegisterForTxResponse
impl StructuralPartialEq for SessionRegisterForTxResponse