pub struct SessionUnregisterForTxRequest {
pub vmos: Vec<u8>,
}Fields
vmos: Vec<u8>Trait Implementations
Sourceimpl Decode<SessionUnregisterForTxRequest, DefaultFuchsiaResourceDialect> for SessionUnregisterForTxRequest
impl Decode<SessionUnregisterForTxRequest, DefaultFuchsiaResourceDialect> for SessionUnregisterForTxRequest
Sourceimpl Encode<SessionUnregisterForTxRequest, DefaultFuchsiaResourceDialect> for &mut SessionUnregisterForTxRequest
impl Encode<SessionUnregisterForTxRequest, DefaultFuchsiaResourceDialect> for &mut SessionUnregisterForTxRequest
Sourceimpl<T0: Encode<Vector<u8, 32>, DefaultFuchsiaResourceDialect>> Encode<SessionUnregisterForTxRequest, DefaultFuchsiaResourceDialect> for (T0,)
impl<T0: Encode<Vector<u8, 32>, DefaultFuchsiaResourceDialect>> Encode<SessionUnregisterForTxRequest, DefaultFuchsiaResourceDialect> for (T0,)
Sourceimpl Hash for SessionUnregisterForTxRequest
impl Hash for SessionUnregisterForTxRequest
Sourceimpl Ord for SessionUnregisterForTxRequest
impl Ord for SessionUnregisterForTxRequest
Sourcefn cmp(&self, other: &SessionUnregisterForTxRequest) -> Ordering
fn cmp(&self, other: &SessionUnregisterForTxRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SessionUnregisterForTxRequest
impl PartialEq for SessionUnregisterForTxRequest
Sourcefn eq(&self, other: &SessionUnregisterForTxRequest) -> bool
fn eq(&self, other: &SessionUnregisterForTxRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for SessionUnregisterForTxRequest
impl PartialOrd for SessionUnregisterForTxRequest
Sourceimpl ResourceTypeMarker for SessionUnregisterForTxRequest
impl ResourceTypeMarker for SessionUnregisterForTxRequest
Sourcetype Borrowed<'a> = &'a mut SessionUnregisterForTxRequest
type Borrowed<'a> = &'a mut SessionUnregisterForTxRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).Sourceimpl TypeMarker for SessionUnregisterForTxRequest
impl TypeMarker for SessionUnregisterForTxRequest
Sourcetype Owned = SessionUnregisterForTxRequest
type Owned = SessionUnregisterForTxRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.impl Eq for SessionUnregisterForTxRequest
impl Standalone<DefaultFuchsiaResourceDialect> for SessionUnregisterForTxRequest
impl StructuralPartialEq for SessionUnregisterForTxRequest