pub struct TxFlags(/* private fields */);Expand description
Flags set by a Client when handing a buffer to a client on the tx path.
Set by Clients on the inbound_flags field of a tx descriptor.
Implementations
Sourceimpl TxFlags
impl TxFlags
Sourcepub const TX_ACCEL_0: TxFlags
pub const TX_ACCEL_0: TxFlags
Acceleration flag 0.
Acceleration flags are mapped to the acceleration features reported by
the [Device] in [Info.tx_accel]. The n-th feature in tx_accel maps
to the TX_ACCEL_n TxFlag.
pub const TX_ACCEL_1: TxFlags
pub const TX_ACCEL_2: TxFlags
pub const TX_ACCEL_3: TxFlags
pub const TX_ACCEL_4: TxFlags
pub const TX_ACCEL_5: TxFlags
pub const TX_ACCEL_6: TxFlags
pub const TX_ACCEL_7: TxFlags
pub const TX_ACCEL_8: TxFlags
pub const TX_ACCEL_9: TxFlags
pub const TX_ACCEL_10: TxFlags
pub const TX_ACCEL_11: TxFlags
pub const TX_ACCEL_12: TxFlags
pub const TX_ACCEL_13: TxFlags
pub const TX_ACCEL_14: TxFlags
pub const TX_ACCEL_15: TxFlags
Sourceimpl TxFlags
impl TxFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<TxFlags>
pub const fn from_bits(bits: u32) -> Option<TxFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> TxFlags
pub const fn from_bits_truncate(bits: u32) -> TxFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> TxFlags
pub const fn from_bits_retain(bits: u32) -> TxFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<TxFlags>
pub fn from_name(name: &str) -> Option<TxFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: TxFlags) -> bool
pub const fn intersects(&self, other: TxFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: TxFlags) -> bool
pub const fn contains(&self, other: TxFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: TxFlags)
pub fn remove(&mut self, other: TxFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: TxFlags)
pub fn toggle(&mut self, other: TxFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: TxFlags, value: bool)
pub fn set(&mut self, other: TxFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: TxFlags) -> TxFlags
pub const fn intersection(self, other: TxFlags) -> TxFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: TxFlags) -> TxFlags
pub const fn union(self, other: TxFlags) -> TxFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: TxFlags) -> TxFlags
pub const fn difference(self, other: TxFlags) -> TxFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: TxFlags) -> TxFlags
pub const fn symmetric_difference(self, other: TxFlags) -> TxFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> TxFlags
pub const fn complement(self) -> TxFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl TxFlags
impl TxFlags
Sourcepub const fn iter(&self) -> Iter<TxFlags>
pub const fn iter(&self) -> Iter<TxFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<TxFlags>
pub const fn iter_names(&self) -> IterNames<TxFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl TxFlags
impl TxFlags
pub fn from_bits_allow_unknown(bits: u32) -> TxFlags
pub fn has_unknown_bits(&self) -> bool
pub fn get_unknown_bits(&self) -> u32