pub type VmoId = u8;Expand description
VMO identifier.
VMO identifiers are always in the range [0, MAX_DATA_VMOS).
VMO identifiers are reported to device implementations and used to locate buffers.
pub type VmoId = u8;VMO identifier.
VMO identifiers are always in the range [0, MAX_DATA_VMOS).
VMO identifiers are reported to device implementations and used to locate buffers.